@@ -130,7 +130,7 @@ Action::WaypointSet::perform()
 	for(; i != end; ++i)
 	{
 		try { iters.push_back(value_node->find(*i)); }
-		catch(synfig::Exception::NotFound)
+		catch (const synfig::Exception::NotFound&)
 		{
 			throw Error(_("Unable to find waypoint"));
 		}
@@ -182,7 +182,10 @@ Action::WaypointSet::perform()
 									oend = overwritten_waypoints.end();
 		for(; oi != oend; ++oi)
 		{
-			value_node->erase(*oi);
+			// possible earlier waypoints removed and added again, but for now
+			// we do not need to delete them, because we move them in rescaling function
+			// and that function cannot find waypoint to move
+			//value_node->erase(*oi);
 		}
 	}
 
@@ -232,7 +235,7 @@ Action::WaypointSet::undo()
 	for(; i != end; ++i)
 	{
 		try { iter = value_node->find(*i); }
-		catch(synfig::Exception::NotFound)
+		catch (const synfig::Exception::NotFound&)
 		{
 			throw Error(_("Unable to find waypoint"));
 		}
